ProfileMenuOptionGroup class

A feature anchor that represents a group of profile menu options that will be displayed in the profile menu hook.

Inheritance
  • Object
  • FeatureAnchor
  • ProfileMenuOptionGroup

Constructors

ProfileMenuOptionGroup({int order = 0, required List<ProfileMenuOption> options})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hookName → String
no setteroverride
options → List<ProfileMenuOption>
final
order → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited